@@ -21,6 +21,8 @@ var t = System.currentTimeMillis();
 this.binaryDoc.setBigEndian(true);
 var msgMap = ( new JU.MessagePackReader(this.binaryDoc, false)).readMap();
 this.binaryDoc.close();
+var encoder = msgMap.get("encoder");
+System.out.println("BCIFReader: BCIF encoder " + encoder);
 this.version = msgMap.get("version");
 System.out.println("BCIFReader: BCIF version " + this.version);
 var dataBlock = (msgMap.get("dataBlocks"))[0];
@@ -43,7 +45,7 @@ Clazz.defineMethod(c$, "processCategory",
 function(cat){
 var catName = (cat.get("name")).toLowerCase();
 if (!this.isCategoryOfInterest(catName)) return false;
-this.bcifParser.initializeCategory(catName, J.adapter.readers.cif.BCIFDecoder.geMapInt(cat.get("rowCount")), cat.get("columns"));
+this.bcifParser.initializeCategory(catName, J.adapter.readers.cif.BCIFDecoder.geMapInt(cat.get("rowCount"), null), cat.get("columns"));
 this.processCategoryName(catName);
 return false;
 }, "java.util.Map");
@@ -131,9 +133,9 @@ function(){
 if (this.bcifParser.fieldStr != null) this.firstChar = this.bcifParser.fieldStr.charAt(0);
 return this.bcifParser.isFieldValid();
 });
-Clazz.overrideMethod(c$, "parseIntField", 
+Clazz.defineMethod(c$, "parseIntField", 
 function(){
-return this.bcifParser.ifield;
+return (this.bcifParser.ifield == -2147483648 ? Clazz.superCall(this, J.adapter.readers.cif.BCIFReader, "parseIntField", []) : this.bcifParser.ifield);
 });
 Clazz.overrideMethod(c$, "parseFloatField", 
 function(){
@@ -155,4 +157,4 @@ return this.bcifParser.dfield;
 }, "~N");
 c$.temp = null;
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
