@@ -260,4 +260,4 @@ function(){
 return "[JmolObject " + this.id + " " + (this.bsAtoms == null ? "" : this.bsAtoms.cardinality() + " atoms") + "]";
 });
 });
-;//5.0.1-v2 Fri Jul 26 07:56:23 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
