@@ -1162,4 +1162,4 @@ return this.atoms[iPrev].chainID != this.atoms[i].chainID;
 }, "~N,~N");
 c$.nucleic = " A C G T U ADE THY CYT GUA URI DA DC DG DT DU ";
 });
-;//5.0.1-v2 Fri Jul 26 07:57:22 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
