@@ -170,4 +170,4 @@ if (f == null) JU.Logger.error("Exponent for " + code + " not found");
 return  new J.quantum.SlaterData(iAtom, x, y, z, r, zeta, 1);
 }, "~N,~S,~S");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
