@@ -396,4 +396,4 @@ if (charge != 0) name += "<sup>" + Math.abs(charge) + (charge > 0 ? "+" : charge
 }return name;
 }, "JM.Atom");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
