@@ -1322,4 +1322,4 @@ function(pt, prec){
 if (this.floatifyJavaDouble) JU.PT.fixPtFloats(pt, prec);
 }, "JU.P3,~N");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
