@@ -352,10 +352,10 @@ if (this.acr.doConvertToFractional || this.acr.fileCoordinatesAreFractional) {
 this.setLatticeCells();
 var doApplySymmetry = true;
 if (this.acr.ignoreFileSpaceGroupName || !this.acr.iHaveSymmetryOperators) {
+if (!this.acr.merging || readerSymmetry == null) readerSymmetry =  new J.adapter.smarter.XtalSymmetry.FileSymmetry();
 if (this.acr.unitCellParams[0] == 0 && this.acr.unitCellParams[2] == 0) {
 JU.SimpleUnitCell.fillParams(null, null, null, this.acr.unitCellParams);
-}if (!this.acr.merging || readerSymmetry == null) readerSymmetry =  new J.adapter.smarter.XtalSymmetry.FileSymmetry();
-doApplySymmetry = readerSymmetry.createSpaceGroup(this.acr.desiredSpaceGroupIndex, (this.acr.sgName.indexOf("!") >= 0 ? "P1" : this.acr.sgName), this.acr.unitCellParams, this.acr.modDim);
+}doApplySymmetry = readerSymmetry.createSpaceGroup(this.acr.desiredSpaceGroupIndex, (this.acr.sgName.indexOf("!") >= 0 ? "P1" : this.acr.sgName), this.acr.unitCellParams, this.acr.modDim);
 } else {
 this.acr.doPreSymmetry();
 readerSymmetry = null;
@@ -966,13 +966,20 @@ if (this.asc.bsAtoms != null) this.asc.bsAtoms.set(atom1.index);
 if (spinOp != 0 && atom1.vib != null) {
 sym.getSpaceGroupOperation(iSym).rotate(atom1.vib);
 atom1.vib.scale(spinOp);
-}if (atom1.isNegDisorder) {
+}if (atom1.part < 0) {
+var key = Integer.$valueOf(iSym * 1000 + 500 + atom1.part);
 if (this.disorderMap == null) this.disorderMap =  new java.util.Hashtable();
-var key = Integer.$valueOf(iSym * 1000 + atom1.altLoc.charCodeAt(0));
 var ch = this.disorderMap.get(key);
 if (ch == null) {
-if (this.disorderMapMax == 0 || this.disorderMapMax == 90) this.disorderMapMax = ('@').charCodeAt(0);
-this.disorderMap.put(key, ch =  new Character(String.fromCharCode(++this.disorderMapMax)));
+var ia = Integer.$valueOf(atom1.part);
+var isNew = (this.disorderMap.get(ia) == null);
+if (this.disorderMapMax == 0 || this.disorderMapMax == 122) {
+this.disorderMapMax = 64;
+} else if (this.disorderMapMax == 90) {
+this.disorderMapMax = 96;
+}ch =  new Character(isNew ? atom1.altLoc : String.fromCharCode(++this.disorderMapMax));
+this.disorderMap.put(key, ch);
+if (isNew) this.disorderMap.put(ia, ch);
 }atom1.altLoc = ch.charValue();
 }atom1.atomSite = atomSite;
 if (code != null) atom1.altLoc = subSystemId;
@@ -1004,13 +1011,24 @@ if (ia1 > ia2) {
 var i = ia1;
 ia1 = ia2;
 ia2 = i;
-}if (ia1 != ia2 && (ia1 >= bondAtomMin || ia2 >= bondAtomMin) && this.bondsFound.indexOf(key = "-" + ia1 + "," + ia2) < 0) {
+}if ((ia1 != ia2 && (ia1 >= bondAtomMin || ia2 >= bondAtomMin)) && this.bondsFound.indexOf(key = "-" + ia1 + "," + ia2) < 0) {
 this.bondsFound.append(key);
 this.asc.addNewBondWithOrder(ia1, ia2, bond.order);
 }}
 }}
 return pt;
 }, "~N,~N,~N,~N,~N,~N,~A,J.adapter.smarter.MSInterface,JU.BS,~A");
+Clazz.defineMethod(c$, "setPartProperty", 
+function(){
+for (var iset = this.asc.atomSetCount; --iset >= 0; ) {
+var parts =  Clazz.newFloatArray (this.asc.getAtomSetAtomCount(iset), 0);
+for (var i = 0, ia = this.asc.getAtomSetAtomIndex(iset), n = parts.length; i < n; i++) {
+var a = this.asc.atoms[ia++];
+parts[i] = a.part;
+}
+this.asc.setAtomProperties("part", parts, iset, false);
+}
+});
 Clazz.defineMethod(c$, "trimToUnitCell", 
 function(iAtomFirst){
 var atoms = this.asc.atoms;
@@ -1159,4 +1177,4 @@ this.addSpaceGroupOperation(s, 0);
 });
 /*eoif3*/})();
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
