@@ -1,5 +1,5 @@
 Clazz.declarePackage("J.adapter.writers");
-Clazz.load(["J.adapter.writers.XtlWriter", "J.api.JmolWriter", "JU.P3"], "J.adapter.writers.CIFWriter", ["JU.BS", "$.PT", "$.SB", "JV.Viewer"], function(){
+Clazz.load(["J.adapter.writers.XtlWriter", "J.api.JmolWriter", "JU.P3"], "J.adapter.writers.CIFWriter", ["JU.BS", "$.PT", "$.SB", "JU.BSUtil", "JV.Viewer"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.vwr = null;
 this.oc = null;
@@ -18,14 +18,19 @@ this.isP1 = (data != null && data.length > 0 && "P1".equals(data[0]));
 Clazz.overrideMethod(c$, "write", 
 function(bs){
 if (bs == null) bs = this.vwr.bsA();
+ else bs = JU.BSUtil.copy(bs);
 try {
 var mi = this.vwr.ms.at[bs.nextSetBit(0)].mi;
-var uc = this.vwr.getCurrentUnitCell();
+var n0 = bs.cardinality();
+bs.and(this.vwr.getModelUndeletedAtomsBitSet(mi));
+if (n0 < bs.cardinality()) {
+System.err.println("CIFWriter Warning: Atoms not in model " + (mi + 1) + " ignored");
+}var uc = this.vwr.ms.getUnitCell(mi);
 this.haveUnitCell = (uc != null);
 if (!this.haveUnitCell) uc = this.vwr.getSymTemp().setUnitCellFromParams(null, false, 0.00001);
 this.slop = uc.getPrecision();
-this.isHighPrecision = (this.slop == 1.0E-12);
 this.precision = Clazz.doubleToInt(-Math.log10(this.slop));
+this.isHighPrecision = (this.slop == 1.0E-12);
 var offset = uc.getFractionalOffset();
 var fractionalOffset = offset != null && (offset.x != Clazz.floatToInt(offset.x) || offset.y != Clazz.floatToInt(offset.y) || offset.z != Clazz.floatToInt(offset.z));
 var fset;
@@ -97,6 +102,7 @@ if (atoms[i].altloc != '\0') {
 haveAltLoc = true;
 break;
 }}
+var parts = (haveAltLoc ? this.vwr.getDataObj("property_part", bsOut, 1) : null);
 var sbLength = sb.length();
 sb.append("\n\nloop_\n_atom_site_label\n_atom_site_type_symbol\n_atom_site_fract_x\n_atom_site_fract_y\n_atom_site_fract_z");
 if (haveAltLoc) {
@@ -111,7 +117,7 @@ jmol_atom.append("\n\nloop_\n_jmol_atom_index\n_jmol_atom_name\n_jmol_atom_site_
 var nAtoms = 0;
 var p =  new JU.P3();
 var elemNums =  Clazz.newIntArray (130, 0);
-for (var i = bsOut.nextSetBit(0); i >= 0; i = bsOut.nextSetBit(i + 1)) {
+for (var pi = 0, i = bsOut.nextSetBit(0); i >= 0; i = bsOut.nextSetBit(i + 1)) {
 var a = atoms[i];
 p.setT(a);
 if (this.haveUnitCell) {
@@ -125,7 +131,14 @@ if (elements.indexOf(key) < 0) elements += key;
 var label = sym + ++elemNums[elemno];
 sb.append(JU.PT.formatS(label, 5, 0, true, false)).append(" ").append(JU.PT.formatS(sym, 3, 0, true, false)).append(this.clean(p.x)).append(this.clean(p.y)).append(this.clean(p.z));
 if (haveAltLoc) {
-sb.append(" ").appendC(a.altloc == '\0' ? '.' : a.altloc);
+sb.append(" ");
+var sdis;
+if (parts != null) {
+var part = Clazz.floatToInt(parts[pi++]);
+sdis = (part == 0 ? "." : "" + part);
+} else {
+sdis = "" + (a.altloc == '\0' ? '.' : a.altloc);
+}sb.append(sdis);
 }if (haveOccupancy) sb.append(" ").append(this.clean(occ[i] / 100));
  else if (!this.haveUnitCell) sb.append(this.clean(a.x)).append(this.clean(a.y)).append(this.clean(a.z));
 sb.append("\n");
@@ -216,4 +229,4 @@ return (this.oc == null ? "" : this.oc.toString());
 });
 c$.fset0 = JU.P3.new3(555, 555, 1);
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
