@@ -41,6 +41,7 @@ var bondCount = this.vwr.ms.bondCount;
 var bonds = this.vwr.ms.bo;
 for (var i = 0; i < bondCount; i++) {
 var bond = bonds[i];
+if (bond == null) continue;
 var a1 = bond.atom1;
 var a2 = bond.atom2;
 if (!bsAtoms.get(a1.i) || !bsAtoms.get(a2.i)) continue;
@@ -98,4 +99,4 @@ function(){
 return (this.oc == null ? "" : this.oc.toString());
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
