@@ -176,6 +176,7 @@ return (this.ptTemp == null ? null : this.ptTemp.toString());
 }, "JM.Atom,~N");
 Clazz.defineMethod(c$, "getBondRecordMOL", 
 function(mol, n, b, atomMap, asV3000, asJSON, noAromatic, is2d){
+if (b == null) return;
 var a1 = atomMap[b.atom1.i];
 var a2 = atomMap[b.atom2.i];
 var order = b.getValence();
@@ -249,4 +250,4 @@ mol.append("\n");
 }
 }, "JU.SB,~S,~N");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
