@@ -28,4 +28,4 @@ function(vwr, state){
 return J.api.Interface.getInterface("JS.Symmetry", vwr, state);
 }, "JV.Viewer,~S");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
