@@ -2,4 +2,4 @@ Clazz.declarePackage("J.api");
 (function(){
 var c$ = Clazz.declareType(J.api, "JmolAdapterBondIterator", null);
 })();
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
