@@ -224,4 +224,4 @@ this.output(" V2 " + this.triad(ptC));
 this.outputTextureCode();
 }, "JU.T3,JU.T3,JU.T3,~N");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
