@@ -228,4 +228,4 @@ Clazz.overrideMethod(c$, "plotText",
 function(x, y, z, colix, text, font3d){
 }, "~N,~N,~N,~N,~S,JU.Font");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
