@@ -328,4 +328,4 @@ this.gdata.plotText(x, y, z, this.gdata.getColorArgbOrGray(colix), 0, text, font
 this.outputComment("end text " + this.nText + ": " + text);
 }, "~N,~N,~N,~N,~S,JU.Font");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
