@@ -8,4 +8,4 @@ function(vwr, files, width, height, fps, fileName){
 return this.errorMsg;
 }, "JV.Viewer,~A,~N,~N,~N,~S");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
