@@ -37,4 +37,4 @@ this.volumetricVectors[1].set(0, (ymax - ymin) / this.nPointsY, 0);
 this.volumetricVectors[2].set((zmax - zmin) / this.nPointsZ, 0, 0);
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
