@@ -202,4 +202,4 @@ function(){
 return (this.isBinary ? this.binarydoc.readFloat() : this.parseFloatStr(this.nextToken()));
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
