@@ -53,4 +53,4 @@ var x = Clazz.doubleToInt(Math.floor(5 * this.imageFontScaling));
 this.g3d.drawStringNoSlab(frameTitle, null, x, y, 0, 0);
 }, "~S");
 });
-;//5.0.1-v2 Tue Jul 23 19:27:37 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
