@@ -261,4 +261,4 @@ if (this.dotsOrDashes && (this.dashDots == null || this.dashDots === J.render.Fo
 return this.drawLine2(this.g3d, x1, y1, z1, x2, y2, z2, diameter);
 }, "~N,~N,~N,~N,~N,~N,~N");
 });
-;//5.0.1-v2 Tue Jul 23 19:27:37 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
