@@ -76,12 +76,12 @@ var needTranslucent = false;
 if (this.isPass2) {
 if (!this.isExport) for (var i = this.bsForPass2.nextSetBit(0); i >= 0; i = this.bsForPass2.nextSetBit(i + 1)) {
 this.bond = bonds[i];
-this.renderBond();
+if (this.bond != null) this.renderBond();
 }
 } else {
 for (var i = this.ms.bondCount; --i >= 0; ) {
 this.bond = bonds[i];
-if ((this.bond.shapeVisibilityFlags & this.myVisibilityFlag) != 0 && this.renderBond()) {
+if (this.bond != null && (this.bond.shapeVisibilityFlags & this.myVisibilityFlag) != 0 && this.renderBond()) {
 needTranslucent = true;
 this.bsForPass2.set(i);
 }}
@@ -410,4 +410,4 @@ this.g3d.setC(this.colixB);
 this.g3d.fillHermite(5, w, w, w, this.pointT, this.pointT2, this.pointT3, this.pointT3);
 }, "JM.Atom,JM.Atom,JU.V3,~N");
 });
-;//5.0.1-v2 Wed Jul 24 13:47:37 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
