@@ -324,4 +324,4 @@ var width = Clazz.floatToInt(this.isExport ? mad : this.vwr.tm.scaleToScreen(Cla
 this.g3d.fillCylinderXYZ(colixA, colixB, 3, width, xA, yA, zA, xB, yB, zB);
 }}, "JM.Atom,JM.Atom,~N,~N,~N");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
