@@ -79,4 +79,4 @@ this.g3d.setC(this.colix);
 this.g3d.drawPoints(nPoints, this.scrCoords, this.dotScale);
 }, "~N");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
