@@ -55,4 +55,4 @@ this.g3d.fillTriangle3CNBits(this.facePt1, this.colix, p1, this.facePt2, this.co
 }
 }, "JU.BS");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
