@@ -132,4 +132,4 @@ if ((edgeMask & 2) == 2) this.g3d.fillCylinderBits(3, d, b, c);
 if ((edgeMask & 4) == 4) this.g3d.fillCylinderBits(3, d, a, c);
 }}, "~N,JU.P3,JU.P3,JU.P3,~N");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
