@@ -120,7 +120,7 @@ thisSlabValue = Math.round(z0 + (z1 - z0) * (100 - this.meshSlabValue) / 100);
 this.frontOnly = new Boolean (this.frontOnly & (this.meshSlabValue >= 100)).valueOf();
 this.isShell = new Boolean (this.isShell & (this.meshSlabValue >= 100)).valueOf();
 }}var tCover = this.vwr.gdata.translucentCoverOnly;
-this.vwr.gdata.translucentCoverOnly = (this.frontOnly || !this.vwr.getBoolean(603979967));
+this.vwr.gdata.translucentCoverOnly = (this.frontOnly || !this.vwr.getBoolean(1111490588));
 this.thePlane = this.imesh.jvxlData.jvxlPlane;
 this.vertexValues = this.mesh.vvs;
 var isOK;
@@ -376,4 +376,4 @@ this.g3d.drawLineAB(this.pt1f, this.pt2f);
 }}
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
