@@ -129,7 +129,7 @@ this.currentMesh.color = this.color;
 }this.setTokenProperty(1765808134, false, false);
 return;
 }if ("translucency" === propertyName) {
-this.setTokenProperty(603979967, ((value).equals("translucent")), false);
+this.setTokenProperty(1111490588, ((value).equals("translucent")), false);
 return;
 }if ("hidden" === propertyName) {
 value = Integer.$valueOf((value).booleanValue() ? 1073742334 : 1073742335);
@@ -256,7 +256,7 @@ return;
 case 1765808134:
 m.colix = this.colix;
 return;
-case 603979967:
+case 1111490588:
 m.setTranslucent(bProp, this.translucentLevel);
 if (bProp && m.bsSlabGhost != null) m.resetSlab();
 return;
@@ -476,4 +476,4 @@ map.put("type", this.myType);
 }return map;
 }, "JU.T3,~N");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
