@@ -102,7 +102,7 @@ function(){
 var bonds = this.ms.bo;
 for (var i = this.ms.bondCount; --i >= 0; ) {
 var bond = bonds[i];
-if ((bond.shapeVisibilityFlags & this.vf) == 0 || this.ms.isAtomHidden(bond.atom1.i) || this.ms.isAtomHidden(bond.atom2.i)) continue;
+if (bond == null || (bond.shapeVisibilityFlags & this.vf) == 0 || this.ms.isAtomHidden(bond.atom1.i) || this.ms.isAtomHidden(bond.atom2.i)) continue;
 bond.atom1.setClickable(this.vf);
 bond.atom2.setClickable(this.vf);
 }
@@ -148,7 +148,7 @@ var v =  new JU.P3();
 var bonds = this.ms.bo;
 for (var i = this.ms.bondCount; --i >= 0; ) {
 var bond = bonds[i];
-if (bond.shapeVisibilityFlags == 0) continue;
+if (bond == null || bond.shapeVisibilityFlags == 0) continue;
 var atom1 = bond.atom1;
 var atom2 = bond.atom2;
 if (!atom1.checkVisible() || !atom2.checkVisible()) continue;
@@ -165,4 +165,4 @@ pt.setT(v);
 return pickedBond;
 }, "~N,~N,JU.BS,JU.P3,~A");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
