@@ -117,7 +117,7 @@ this.setColixDipole(this.colix, 1023, bs);
 this.setPropertyTok(1765808134, false, 0, 0);
 }return;
 }if ("translucency" === propertyName) {
-this.setPropertyTok(603979967, this.isBond, (value.equals("translucent") ? 1 : 0), 0);
+this.setPropertyTok(1111490588, this.isBond, (value.equals("translucent") ? 1 : 0), 0);
 return;
 }if ("clear" === propertyName) {
 this.currentDipole = null;
@@ -278,7 +278,7 @@ return;
 case 1765808134:
 dipole.colix = this.colix;
 return;
-case 603979967:
+case 1111490588:
 dipole.setTranslucent(iValue == 1, this.translucentLevel);
 return;
 }
@@ -496,4 +496,4 @@ J.shape.Shape.appendCmd(s, J.shape.Shape.getColorCommandUnk("dipole", dipole.col
 return s.toString();
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
