@@ -398,4 +398,4 @@ if (this.scale != 1) sb.append("; scale:" + this.scale);
 sb.append("\n");
 }, "JU.SB");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
