@@ -543,4 +543,4 @@ cp.xVdwClash = ((x / 2));
 }}, "JU.ContactPair,~N,~N,~N,~N");
 c$.rdVDW =  new J.atomdata.RadiusData(null, 1, J.atomdata.RadiusData.EnumType.FACTOR, J.c.VDW.AUTO);
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
