@@ -218,4 +218,4 @@ this.lcaoReverseColor = lc.lcaoReverseColor;
 Clazz.superCall(this, J.shapesurface.LcaoCartoon, "merge", [shape]);
 }, "J.shape.MeshCollection");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
