@@ -7,6 +7,7 @@ this.moPlane = null;
 this.moCutoff = null;
 this.moResolution = null;
 this.moScale = null;
+this.moSelection = null;
 this.moColorPos = null;
 this.moColorNeg = null;
 this.moMonteCarloCount = null;
@@ -76,6 +77,9 @@ return;
 }if ("scale" === propertyName) {
 this.thisModel.put("moScale", value);
 return;
+}if ("select" === propertyName) {
+this.thisModel.put("moSelection", value);
+return;
 }if ("squareData" === propertyName) {
 if (value === Boolean.TRUE) this.thisModel.put("moSquareData", Boolean.TRUE);
  else this.thisModel.remove("moSquareData");
@@ -300,6 +304,7 @@ this.moCutoff = Float.$valueOf(0.05);
 }this.thisModel.put("moCutoff", Float.$valueOf(this.moCutoff.floatValue()));
 this.moResolution = this.thisModel.get("moResolution");
 this.moScale = this.thisModel.get("moScale");
+this.moSelection = this.thisModel.get("moSelection");
 this.moColorPos = this.thisModel.get("moColorPos");
 this.moColorNeg = this.thisModel.get("moColorNeg");
 this.moSquareData = this.thisModel.get("moSquareData");
@@ -321,6 +326,7 @@ this.setPropI("reset", this.strID, null);
 if (this.moDebug) this.setPropI("debug", Boolean.TRUE, null);
 this.getSettings(this.strID);
 if (this.moScale != null) this.setPropI("scale", this.moScale, null);
+if (this.moSelection != null) this.setPropI("select", this.moSelection, null);
 if (this.moResolution != null) this.setPropI("resolution", this.moResolution, null);
 if (this.moPlane != null) {
 this.setPropI("plane", this.moPlane, null);
@@ -369,7 +375,11 @@ if (modelCount > 1) J.shape.Shape.appendCmd(s, "frame " + this.vwr.getModelNumbe
 if (this.nboType != null) J.shape.Shape.appendCmd(s, "nbo type " + this.nboType);
 if (this.moCutoff != null) J.shape.Shape.appendCmd(s, this.myType + " cutoff " + (this.sg.params.isPositiveOnly ? "+" : "") + this.moCutoff);
 if (this.moScale != null) J.shape.Shape.appendCmd(s, this.myType + " scale " + this.moScale);
-if (this.moMonteCarloCount != null) J.shape.Shape.appendCmd(s, this.myType + " points " + this.moMonteCarloCount + " " + this.moRandomSeed);
+if (this.moSelection != null) {
+s.append("try{/*16.2*/\n");
+J.shape.Shape.appendCmd(s, this.myType + " select " + this.moSelection);
+s.append("}catch{};\n");
+}if (this.moMonteCarloCount != null) J.shape.Shape.appendCmd(s, this.myType + " points " + this.moMonteCarloCount + " " + this.moRandomSeed);
 if (this.moResolution != null) J.shape.Shape.appendCmd(s, this.myType + " resolution " + this.moResolution);
 if (this.moPlane != null) J.shape.Shape.appendCmd(s, this.myType + " plane {" + this.moPlane.x + " " + this.moPlane.y + " " + this.moPlane.z + " " + this.moPlane.w + "}");
 if (this.moTitleFormat != null) J.shape.Shape.appendCmd(s, this.myType + " titleFormat " + JU.PT.esc(this.moTitleFormat));
@@ -409,4 +419,4 @@ this.htModels.put(key, entry.getValue());
 }Clazz.superCall(this, J.shapesurface.MolecularOrbital, "merge", [shape]);
 }, "J.shape.MeshCollection");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
