@@ -193,4 +193,4 @@ if ((check & 2) != 0) this.outputEdge(iB, iC, color);
 if ((check & 4) != 0) this.outputEdge(iC, iA, color);
 }, "~N,~N,~N,~N,~N");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
