@@ -128,4 +128,4 @@ this.transformManager.rotateYRadians((this.transformManager.spinY * 0.0174532925
 this.transformManager.rotateZRadians((this.transformManager.spinZ * 0.017453292519943295 / this.myFps));
 }}});
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
