@@ -911,6 +911,10 @@ vwr.ms.getSurfaceDistanceMax();
 return this.getSurfaceDistance100() / 100;
 case 1111492620:
 return this.getBfactor100() / 100;
+case 1111490588:
+return JU.C.getColixTranslucencyFractional(this.colixAtom);
+case 1312817669:
+return this.getVolume(vwr, J.c.VDW.AUTO);
 case 1111490577:
 return this.getFractionalUnitCoord(!vwr.g.legacyJavaFloat, 'X', ptTemp);
 case 1111490578:
@@ -942,8 +946,6 @@ case 1111490581:
 return this.getVib('2');
 case 1111490582:
 return this.getVib('3');
-case 1312817669:
-return this.getVolume(vwr, J.c.VDW.AUTO);
 case 1145047050:
 case 1145047053:
 case 1145045006:
@@ -1157,4 +1159,4 @@ return 0;
 });
 c$.MAD_GLOBAL = 32200;
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
