@@ -288,7 +288,7 @@ var am = this.ms.am;
 var bo = this.ms.bo;
 for (var i = this.ms.bondCount; --i >= 0; ) {
 var bond = bo[i];
-if ((bond.order & 28672) != 0 && am[bond.atom1.mi].trajectoryBaseIndex == this.modelIndex) bsDelete.set(i);
+if (bond != null && (bond.order & 28672) != 0 && am[bond.atom1.mi].trajectoryBaseIndex == this.modelIndex) bsDelete.set(i);
 }
 if (bsDelete.nextSetBit(0) >= 0) this.ms.deleteBonds(bsDelete, false);
 this.getRasmolHydrogenBonds(bs, bs, null, false, 2147483647, false, null, dsspVersion);
@@ -298,4 +298,4 @@ function(dssrData, dataType){
 if (this.auxiliaryInfo.containsKey("dssr")) this.vwr.getAnnotationParser(true).getAtomicDSSRData(this.ms, this.modelIndex, dssrData, dataType);
 }, "~A,~S");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
