@@ -30,7 +30,7 @@ var models = this.ms.am;
 var bonds = this.ms.bo;
 for (var i = this.ms.bondCount; --i >= 0; ) {
 var bond = bonds[i];
-if ((bond.order & 28672) == 0) continue;
+if (bond == null || (bond.order & 28672) == 0) continue;
 if (bsAtoms.get(bond.atom1.i)) bsDelete.set(i);
  else bsOK.set(models[bond.atom1.mi].trajectoryBaseIndex);
 }
@@ -338,6 +338,7 @@ if (bs == null) bs =  new JU.BS();
 var pt0 = pt;
 while (pt < len && JU.PT.isDigit(identifier.charAt(pt))) ++pt;
 
+if (pt == pt0) return null;
 var seqNumber = 0;
 try {
 seqNumber = Integer.parseInt(identifier.substring(pt0, pt));
@@ -656,4 +657,4 @@ function(s, atomName, aaRet){
 return this.getBioExt().getAminoAcidValenceAndCharge(s, atomName, aaRet);
 }, "~S,~S,~A");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
