@@ -1,5 +1,5 @@
 Clazz.declarePackage("JM");
-Clazz.load(["JM.AtomCollection", "JU.V3"], "JM.BondCollection", ["JU.AU", "$.BS", "$.Measure", "JM.Bond", "$.BondIteratorSelected", "$.BondSet", "$.HBond", "JU.BSUtil", "$.C", "$.Edge"], function(){
+Clazz.load(["JM.AtomCollection", "JU.V3"], "JM.BondCollection", ["JU.AU", "$.BS", "$.Measure", "JM.Bond", "$.BondIteratorSelected", "$.BondSet", "$.HBond", "JU.C", "$.Edge"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.bo = null;
 this.bondCount = 0;
@@ -54,7 +54,7 @@ return JU.C.getColixInherited(this.bo[i].colix, this.bo[i].atom2.colixAtom);
 Clazz.defineMethod(c$, "getBondCountInModel", 
 function(modelIndex){
 var n = 0;
-for (var i = this.bondCount; --i >= 0; ) if (this.bo[i].atom1.mi == modelIndex) n++;
+for (var i = this.bondCount; --i >= 0; ) if (this.bo[i] != null && this.bo[i].atom1.mi == modelIndex) n++;
 
 return n;
 }, "~N");
@@ -81,6 +81,7 @@ if (bond != null) bs.set(bond.index);
 }
 for (var iBond = 0; iBond < this.bondCount; ++iBond) {
 var bond = this.bo[iBond];
+if (bond == null) continue;
 var isSelected1 = bsAtoms.get(bond.atom1.i);
 var isSelected2 = bsAtoms.get(bond.atom2.i);
 if (bondSelectionModeOr ? isSelected1 || isSelected2 : isSelected1 && isSelected2) bs.set(iBond);
@@ -163,6 +164,7 @@ Clazz.defineMethod(c$, "deleteAllBonds2",
 function(){
 this.vwr.setShapeProperty(1, "reset", null);
 for (var i = this.bondCount; --i >= 0; ) {
+if (this.bo[i] == null) continue;
 this.bo[i].deleteAtomReferences();
 this.bo[i] = null;
 }
@@ -195,7 +197,7 @@ if (a.bonds != null) for (var j = a.bonds.length; --j >= 0; ) if (bsB.get(a.getB
 }
 }for (var i = bsBonds.nextSetBit(0); i < this.bondCount && i >= 0; i = bsBonds.nextSetBit(i + 1)) {
 var bond = this.bo[i];
-if (!this.isInRange(bond.atom1, bond.atom2, minD, maxD, minDIsFraction, maxDIsFraction, isFractional)) continue;
+if (bond == null || !this.isInRange(bond.atom1, bond.atom2, minD, maxD, minDIsFraction, maxDIsFraction, isFractional)) continue;
 if (matchNull || newOrder == (bond.order & -257 | 131072) || (order & bond.order & 30720) != 0) {
 bsDelete.set(i);
 nDeleted++;
@@ -218,35 +220,29 @@ return ((minFrac ? dAB >= dABcalc * minD : d2 >= minD) && (maxfrac ? dAB <= dABc
 }, "JM.Atom,JM.Atom,~N,~N,~B,~B,~B");
 Clazz.defineMethod(c$, "dBb", 
 function(bsBond, isFullModel){
-var iDst = bsBond.nextSetBit(0);
-if (iDst < 0) return;
+var n = bsBond.cardinality();
+if (n == 0) return;
 (this).resetMolecules();
 var modelIndexLast = -1;
-var n = bsBond.cardinality();
-for (var iSrc = iDst; iSrc < this.bondCount; ++iSrc) {
-var bond = this.bo[iSrc];
-if (n > 0 && bsBond.get(iSrc)) {
-n--;
+for (var i = bsBond.nextSetBit(0); i >= 0 && i < this.bondCount; i = bsBond.nextSetBit(i + 1)) {
+var bond = this.bo[i];
+if (bond != null && bsBond.get(i)) {
 if (!isFullModel) {
 var modelIndex = bond.atom1.mi;
 if (modelIndex != modelIndexLast) (this).am[modelIndexLast = modelIndex].resetBoundCount();
 }bond.deleteAtomReferences();
-} else {
-this.setBond(iDst++, bond);
+this.bo[i] = null;
 }}
-for (var i = this.bondCount; --i >= iDst; ) this.bo[i] = null;
-
-this.bondCount = iDst;
 var sets = this.vwr.getShapeProperty(1, "sets");
-if (sets != null) for (var i = 0; i < sets.length; i++) JU.BSUtil.deleteBits(sets[i], bsBond);
+if (sets != null) for (var i = 0; i < sets.length; i++) if (sets[i] != null) sets[i].andNot(bsBond);
 
-JU.BSUtil.deleteBits(this.bsAromatic, bsBond);
+this.bsAromatic.andNot(bsBond);
 }, "JU.BS,~B");
 Clazz.defineMethod(c$, "resetAromatic", 
 function(){
 for (var i = this.bondCount; --i >= 0; ) {
 var bond = this.bo[i];
-if (bond.isAromatic()) bond.setOrder(515);
+if (bond != null && bond.isAromatic()) bond.setOrder(515);
 }
 });
 Clazz.defineMethod(c$, "assignAromaticBondsBs", 
@@ -258,6 +254,7 @@ var isAll = (bsBonds == null);
 var i0 = (isAll ? this.bondCount - 1 : bsBonds.nextSetBit(0));
 for (var i = i0; i >= 0; i = (isAll ? i - 1 : bsBonds.nextSetBit(i + 1))) {
 var bond = this.bo[i];
+if (bond == null) continue;
 if (this.bsAromatic.get(i)) bond.setOrder(515);
 switch (bond.order & 131071) {
 case 515:
@@ -422,7 +419,7 @@ var isAll = (bsSelected == null);
 var i0 = (isAll ? this.bondCount - 1 : bsSelected.nextSetBit(0));
 for (var i = i0; i >= 0; i = (isAll ? i - 1 : bsSelected.nextSetBit(i + 1))) {
 bond = this.bo[i];
-if (!bond.is(513)) continue;
+if (bond == null || !bond.is(513)) continue;
 var atom1;
 var atom2 = bond.atom2;
 var n1;
@@ -460,14 +457,15 @@ case 1677721602:
 var bsBonds = specInfo;
 for (var i = bsBonds.nextSetBit(0); i >= 0; i = bsBonds.nextSetBit(i + 1)) {
 if (i < this.bondCount) {
+if (this.bo[i] != null) {
 bs.set(this.bo[i].atom1.i);
 bs.set(this.bo[i].atom2.i);
-} else {
-bsBonds.clear(i);
-}}
+continue;
+}}bsBonds.clear(i);
+}
 return bs;
 case 1073742331:
-for (var i = this.bondCount; --i >= 0; ) if (this.bo[i].isAromatic()) {
+for (var i = this.bondCount; --i >= 0; ) if (this.bo[i] != null && this.bo[i].isAromatic()) {
 bs.set(this.bo[i].atom1.i);
 bs.set(this.bo[i].atom2.i);
 }
@@ -493,7 +491,7 @@ if (bs.nextSetBit(0) >= 0) this.vwr.deleteAtoms(bs, false);
 Clazz.defineMethod(c$, "displayBonds", 
 function(bs, isDisplay){
 if (!isDisplay) this.haveHiddenBonds = true;
-for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) if (i < this.bondCount && this.bo[i].mad != 0) this.bo[i].setShapeVisibility(isDisplay);
+for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) if (i < this.bondCount && this.bo[i] != null && this.bo[i].mad != 0) this.bo[i].setShapeVisibility(isDisplay);
 
 }, "JM.BondSet,~B");
 Clazz.defineMethod(c$, "getAtomsConnected", 
@@ -506,7 +504,7 @@ var ishbond = (intType == 30720);
 var isall = (intType == 65535);
 for (var ibond = 0; ibond < this.bondCount; ibond++) {
 var bond = this.bo[ibond];
-if (isall || bond.is(intType) || ishbond && bond.isHydrogen()) {
+if (bond != null && (isall || bond.is(intType) || ishbond && bond.isHydrogen())) {
 if (isBonds) {
 bsResult.set(ibond);
 } else {
@@ -534,4 +532,4 @@ if (atom2.getElementNumber() == 1) bsAtoms.set(atom2.i);
 }
 }, "JM.Atom,JU.BS");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
