@@ -407,8 +407,10 @@ for (var i = bsAtoms.nextSetBit(0); i >= 0; i = bsAtoms.nextSetBit(i + 1)) parti
 
 var a1 = null;
 for (var i = bTypes.length; --i >= 0; ) {
-a1 = bonds[i].atom1;
-var a2 = bonds[i].atom2;
+var bond = bonds[i];
+if (bond == null) continue;
+a1 = bond.atom1;
+var a2 = bond.atom2;
 var ok1 = bsAtoms.get(a1.i);
 var ok2 = bsAtoms.get(a2.i);
 if (!ok1 && !ok2) continue;
@@ -550,8 +552,10 @@ Clazz.defineMethod(c$, "setBondTypes",
 function(bonds, bondCount, bsAtoms){
 var bTypes =  Clazz.newIntArray (bondCount, 0);
 for (var i = bondCount; --i >= 0; ) {
-var a1 = bonds[i].atom1;
-var a2 = bonds[i].atom2;
+var bond = bonds[i];
+if (bond == null) continue;
+var a1 = bond.atom1;
+var a2 = bond.atom2;
 var ok1 = bsAtoms.get(a1.i);
 var ok2 = bsAtoms.get(a2.i);
 if (!ok1 && !ok2) continue;
@@ -1167,4 +1171,4 @@ c$.types =  Clazz.newIntArray(-1, [0, 1, 34, 5, 546, 3, 13, 21, 37, 9, 17]);
 c$.sbMap =  Clazz.newIntArray(-1, [0, 1, 3, 5, 4, 6, 8, 9, 11]);
 c$.equivalentTypes =  Clazz.newIntArray(-1, [1, 1, 2, 1, 3, 1, 4, 1, 5, 5, 6, 6, 7, 6, 8, 8, 9, 8, 10, 8, 11, 11, 12, 12, 13, 13, 14, 14, 15, 15, 16, 15, 17, 15, 18, 15, 19, 19, 1, 1, 21, 5, 22, 1, 23, 5, 24, 5, 25, 25, 26, 25, 28, 5, 28, 5, 29, 5, 2, 1, 31, 31, 7, 6, 21, 5, 8, 8, 6, 6, 36, 5, 2, 1, 9, 8, 10, 8, 10, 8, 3, 1, 42, 8, 10, 8, 16, 15, 10, 8, 9, 8, 42, 8, 9, 8, 6, 6, 21, 5, 7, 6, 21, 5, 42, 8, 9, 8, 10, 8, 10, 8, 2, 1, 10, 8, 6, 6, 4, 1, 42, 8, 10, 8, 2, 1, 2, 1, 9, 8, 9, 8, 9, 8, 8, 8, 9, 8, 70, 70, 5, 5, 16, 15, 18, 15, 17, 15, 26, 25, 9, 8, 12, 12, 2, 1, 9, 8, 2, 1, 10, 8, 9, 8]);
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
