@@ -283,7 +283,7 @@ var i1;
 var i2;
 for (var i = 0; i < this.rawBondCount; i++) {
 var bond = this.bonds[i];
-if (!this.bsAtoms.get(i1 = bond.atom1.i) || !this.bsAtoms.get(i2 = bond.atom2.i)) continue;
+if (bond == null || !this.bsAtoms.get(i1 = bond.atom1.i) || !this.bsAtoms.get(i2 = bond.atom2.i)) continue;
 if (i2 < i1) {
 var ii = i1;
 i1 = i2;
@@ -573,4 +573,4 @@ return "[minimizer " + this.id + " step " + (this.pFF == null ? 0 : this.pFF.get
 });
 c$.staticID = 0;
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
