@@ -108,7 +108,7 @@ function(){
 if (this.bondCount >= 0) return this.bondCount;
 var bonds = this.ms.bo;
 this.bondCount = 0;
-for (var i = this.ms.bondCount; --i >= 0; ) if (bonds[i].atom1.mi == this.modelIndex) this.bondCount++;
+for (var i = this.ms.bondCount; --i >= 0; ) if (bonds[i] != null && bonds[i].atom1.mi == this.modelIndex) this.bondCount++;
 
 return this.bondCount;
 });
@@ -186,4 +186,4 @@ if ((this.simpleCage = ucell) != null) {
 this.auxiliaryInfo.put("unitCellParams", ucell.getUnitCellParams());
 }}, "J.api.SymmetryInterface");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
