@@ -514,7 +514,7 @@ var isotope = iterAtom.getElementNumber();
 if (addH && JU.Elements.getElementNumber(isotope) == 1) this.jbr.setHaveHsAlready(true);
 var name = iterAtom.getAtomName();
 var charge = (addH ? this.getPdbCharge(group3, name) : iterAtom.getFormalCharge());
-var atom = this.addAtom(isPdbThisModel, iterAtom.getSymmetry(), iterAtom.getAtomSite() + siteBase, isotope, name, charge, iterAtom.getPartialCharge(), iterAtom.getTensors(), iterAtom.getOccupancy(), iterAtom.getBfactor(), iterAtom.getXYZ(), iterAtom.getIsHetero(), iterAtom.getIsNegDisorder(), iterAtom.getSerial(), iterAtom.getSeqID(), group3, iterAtom.getVib(), iterAtom.getAltLoc(), iterAtom.getRadius(), iterAtom.getBondRadius());
+var atom = this.addAtom(isPdbThisModel, iterAtom, name, isotope, siteBase, charge, group3);
 if (haveBonds) this.htAtomMap.put(iterAtom.getUniqueID(), atom);
 }
 if (this.groupCount > 0 && addH) {
@@ -576,7 +576,22 @@ function(group3, name){
 return (group3.equals("ARG") && name.equals("NH1") || group3.equals("LYS") && name.equals("NZ") || group3.equals("HIS") && name.equals("ND1") ? 1 : 0);
 }, "~S,~S");
 Clazz.defineMethod(c$, "addAtom", 
-function(isPDB, atomSymmetry, atomSite, atomicAndIsotopeNumber, atomName, formalCharge, partialCharge, tensors, occupancy, bfactor, xyz, isHetero, isNegDisorder, atomSerial, atomSeqID, group3, vib, alternateLocationID, radius, bondRadius){
+function(isPDB, iterAtom, atomName, atomicAndIsotopeNumber, siteBase, formalCharge, group3){
+var atomSymmetry = iterAtom.getSymmetry();
+var atomSite = iterAtom.getAtomSite() + siteBase;
+var partialCharge = iterAtom.getPartialCharge();
+var tensors = iterAtom.getTensors();
+var occupancy = iterAtom.getOccupancy();
+var bfactor = iterAtom.getBfactor();
+var xyz = iterAtom.getXYZ();
+var isHetero = iterAtom.getIsHetero();
+var isNegDisorder = (iterAtom.getPart() < 0);
+var atomSerial = iterAtom.getSerial();
+var atomSeqID = iterAtom.getSeqID();
+var vib = iterAtom.getVib();
+var alternateLocationID = iterAtom.getAltLoc();
+var radius = iterAtom.getRadius();
+var bondRadius = iterAtom.getBondRadius();
 var specialAtomID = 0;
 var atomType = null;
 if (atomName != null) {
@@ -591,7 +606,7 @@ if (specialAtomID == 2 && "CA".equalsIgnoreCase(group3)) specialAtomID = 0;
 }}var atom = this.ms.addAtom(this.iModel, this.nullGroup, atomicAndIsotopeNumber, atomName, atomType, atomSerial, atomSeqID, atomSite, xyz, radius, vib, formalCharge, partialCharge, occupancy, bfactor, tensors, isHetero, isNegDisorder, specialAtomID, atomSymmetry, bondRadius);
 atom.altloc = alternateLocationID;
 return atom;
-}, "~B,JU.BS,~N,~N,~S,~N,~N,JU.Lst,~N,~N,JU.P3,~B,~B,~N,~N,~S,JU.V3,~S,~N,~N");
+}, "~B,J.api.JmolAdapterAtomIterator,~S,~N,~N,~N,~S");
 Clazz.defineMethod(c$, "checkNewGroup", 
 function(adapter, chainID, group3, groupSequenceNumber, groupInsertionCode, addH, isLegacyHAddition){
 if (chainID != this.currentChainID) {
@@ -1052,4 +1067,4 @@ break;
 return null;
 }, "JV.Viewer,JM.ModelSet,~N,~O,JU.BS");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
