@@ -1356,7 +1356,7 @@ if (this.theTok == 268435968 || this.isUserFunction(token.value.toString())) {
 this.ltoken.set(0, this.setCommand(JS.T.tv(1073741824, 0, token.value)));
 this.setBraceCount = 0;
 break;
-}if (this.theTok != 1073741824 && this.theTok != 268442114 && this.theTok != 12290 && (!JS.T.tokAttr(this.theTok, 536870912))) {
+}if (this.theTok != 1111490588 && this.theTok != 1073741824 && this.theTok != 268442114 && this.theTok != 12290 && (!JS.T.tokAttr(this.theTok, 536870912))) {
 if (this.isNewSet) this.commandExpected();
  else this.errorIntStr2(18, "SET", ": " + this.ident);
 return 4;
@@ -2108,4 +2108,4 @@ JU.Logger.error(this.errorMessage);
 }return false;
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
