@@ -1392,8 +1392,9 @@ var isAll = (bs == null);
 var i0 = (isAll ? 0 : bs.nextSetBit(0));
 var i1 = this.vwr.ms.bondCount;
 for (var i = i0; i >= 0 && i < i1; i = (isAll ? i + 1 : bs.nextSetBit(i + 1))) {
-n++;
 var bond = modelSet.bo[i];
+if (bond == null) continue;
+n++;
 switch (tok) {
 case 1140850691:
 var fv = bond.atom1.distance(bond.atom2);
@@ -1940,4 +1941,4 @@ var f = (this.privateFuncs == null ? null : this.privateFuncs.get(sf));
 return (f == null ? this.vwr.getFunction(sf) : f);
 }, "~S");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
