@@ -98,7 +98,7 @@ function(eval, i, allowNone, ret){
 var translucentLevel = 3.4028235E38;
 if (eval.theTok != 1765808134) --i;
 switch (this.tokAt(i + 1)) {
-case 603979967:
+case 1111490588:
 i++;
 translucentLevel = (this.isFloatParameter(i + 1) ? eval.getTranslucentLevel(++i) : this.vwr.getFloat(570425353));
 break;
@@ -182,4 +182,4 @@ for (var i = bs.nextSetBit(0), pt = 0; i >= 0; i = bs.nextSetBit(i + 1)) p[pt++]
 return p;
 }, "JU.BS");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
