@@ -1334,4 +1334,4 @@ return (isAtoms ? this.addXObj(val) : this.addXBs(JM.BondSet.newBS(val)));
 return false;
 }, "JS.T,JS.SV");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
