@@ -23,4 +23,4 @@ this.vNorm4 =  new JU.V3();
 this.bsTemp =  new JU.BS();
 });
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
