@@ -102,4 +102,4 @@ sb.append("\nNumber of Strands ... " + nS);
 sb.append("\nNumber of Turns ..... " + nT);
 }}, "JU.SB");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
