@@ -1,5 +1,5 @@
 Clazz.declarePackage("JV");
-Clazz.load(["javajs.api.BytePoster", "java.util.Hashtable"], "JV.FileManager", ["java.net.URL", "$.URLEncoder", "JU.AU", "$.Base64", "$.LimitedLineReader", "$.Lst", "$.OC", "$.PT", "$.Rdr", "$.SB", "J.api.Interface", "J.io.FileReader", "JU.Escape", "$.Logger", "JV.JC", "$.JmolAsyncException", "$.Viewer"], function(){
+Clazz.load(["javajs.api.BytePoster", "java.util.Hashtable"], "JV.FileManager", ["java.net.URL", "$.URLEncoder", "JU.AU", "$.Base64", "$.LimitedLineReader", "$.Lst", "$.OC", "$.PT", "$.Rdr", "$.SB", "J.adapter.smarter.Resolver", "J.api.Interface", "J.io.FileReader", "JU.Escape", "$.Logger", "JV.JC", "$.JmolAsyncException", "$.Viewer"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.vwr = null;
 this.spartanDoc = null;
@@ -560,7 +560,7 @@ return names;
 if (name == null) return  Clazz.newArray(-1, [null]);
 if (name.indexOf(":") < 0 && name.indexOf("/") != 0) name = JV.FileManager.addDirectory(this.vwr.getDefaultDirectory(), name);
 if (this.appletDocumentBaseURL == null) {
-if (JU.OC.urlTypeIndex(name) >= 0 || this.vwr.haveAccess(JV.Viewer.ACCESS.NONE) || this.vwr.haveAccess(JV.Viewer.ACCESS.READSPT) && !name.endsWith(".spt") && !name.endsWith("/")) {
+if (JU.OC.urlTypeIndex(name) >= 0 || this.vwr.haveAccess(JV.Viewer.ACCESS.NONE) || this.vwr.haveAccess(JV.Viewer.ACCESS.READSPT) && !name.endsWith(".spt") && !name.endsWith("/") || !this.vwr.haveAccessInternal(name)) {
 try {
 url =  new java.net.URL(Clazz.castNullAs("java.net.URL"), name, null);
 } catch (e) {
@@ -707,7 +707,7 @@ var buf =  Clazz.newByteArray (300, 0);
 is.read(buf, 0, 300);
 is.reset();
 if ((buf[0] & 0xFF) == 0x83) {
-if (buf[10] == 68 && buf[11] == 101 && buf[12] == 110) return "BCifDensity";
+return (J.adapter.smarter.Resolver.checkBCIF(buf, false) ? "BCifDensity" : null);
 }if (buf[0] == 80 && buf[1] == 77 && buf[2] == 1 && buf[3] == 0) return "Pmesh";
 if (buf[208] == 77 && buf[209] == 65 && buf[210] == 80) return "Mrc";
 if (buf[0] == 20 && buf[1] == 0 && buf[2] == 0 && buf[3] == 0) return "DelPhi";
@@ -1010,4 +1010,4 @@ return this.vwr.getJzt().isZipStream(br);
 c$.SIMULATION_PROTOCOL = "http://SIMULATION/";
 c$.scriptFilePrefixes =  Clazz.newArray(-1, ["/*file*/\"", "FILE0=\"", "FILE1=\""]);
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
