@@ -151,27 +151,39 @@ return true;
 v.removeItemAt(0);
 v.removeItemAt(0);
 var bytes = v.removeItemAt(0);
-if (JU.Rdr.isPngZipB(bytes)) {
-params.put("pngImgData", bytes);
-} else {
-this.getImagePixels(this.vwr.fm.getImage(bytes, null, true), params);
-}var oz = this.getOutputChannel(null, null);
+var oz = this.getOutputChannel(null, null);
 errRet[0] = this.writeZipFile(oz, v, "OK JMOL", null);
+params.put("pngAppData", oz.toByteArray());
 params.put("type", "PNGJ");
 type = "Png";
 params.put("pngAppPrefix", "Jmol Type");
-params.put("pngAppData", oz.toByteArray());
-} else if (v.size() == 1) {
+if (JU.Rdr.isPngZipB(bytes)) {
+params.put("pngImgData", bytes);
+} else {
+var image = this.vwr.fm.getImage(bytes, null, true);
+var r = ((Clazz.isClassDefined("JV.OutputManager$1") ? 0 : JV.OutputManager.$OutputManager$1$ ()), Clazz.innerTypeInstance(JV.OutputManager$1, this, Clazz.cloneFinals("image", image, "image", this.f$.image, "params", params, "params", this.f$.params, "params", this.f$.params, "errRet", errRet, "errRet", this.f$.errRet, "out", out)));
+if (false && JV.Viewer.isJS) {
+errRet[0] = "async";
+ new Thread(r).start();
+return true;
+}r.run();
+return errRet[0] == null;
+}} else if (v.size() == 1) {
 var b = v.removeItemAt(0);
 out.write(b, 0, b.length);
 return true;
 } else {
 errRet[0] = this.writeZipFile(out, v, "OK JMOL", null);
 return true;
-}}var ie = J.api.Interface.getInterface("javajs.img." + type + "Encoder", this.vwr, "file");
+}}this.finishImage(errRet, type, out, objImage, params);
+return errRet[0] == null;
+}, "~O,~S,JU.OC,java.util.Map,~A");
+Clazz.defineMethod(c$, "finishImage", 
+function(errRet, type, out, objImage, params){
+var ie = J.api.Interface.getInterface("javajs.img." + type + "Encoder", this.vwr, "file");
 if (ie == null) {
 errRet[0] = "Image encoder type " + type + " not available";
-return false;
+return;
 }var doClose = true;
 try {
 if (type.equals("Gif") && this.vwr.getBoolean(603979962)) params.put("reducedColors", Boolean.TRUE);
@@ -189,8 +201,7 @@ throw e;
 } finally {
 if (doClose) out.closeChannel();
 }
-return (errRet[0] == null);
-}, "~O,~S,JU.OC,java.util.Map,~A");
+}, "~A,~S,JU.OC,~O,java.util.Map");
 Clazz.defineMethod(c$, "getImagePixels", 
 function(objImage, params){
 var w = objImage == null ? -1 : JU.AU.isAI(objImage) ? (params.get("width")).intValue() : this.vwr.apiPlatform.getImageWidth(objImage);
@@ -746,5 +757,24 @@ function(cmd, strCatch){
 var vname = "v__" + ("" + Math.random()).substring(3);
 return "# Jmol script\n{\n\tVar " + vname + " = pathForAllFiles\n\tpathForAllFiles=\"$SCRIPT_PATH$\"\n\ttry{\n\t\t" + cmd + "\n\t}catch(e){" + strCatch + "}\n\tpathForAllFiles = " + vname + "\n}\n";
 }, "~S,~S");
+c$.$OutputManager$1$=function(){
+/*if5*/;(function(){
+var c$ = Clazz.declareAnonymous(JV, "OutputManager$1", null, Runnable);
+Clazz.defineMethod(c$, "run", 
+function(){
+try {
+this.b$["JV.OutputManager"].getImagePixels(this.f$.image, this.f$.params);
+} catch (e) {
+if (Clazz.exceptionOf(e, Exception)){
+e.printStackTrace();
+} else {
+throw e;
+}
+}
+this.b$["JV.OutputManager"].finishImage(this.f$.errRet, "Png", this.f$.out, null, this.f$.params);
+this.f$.out.closeChannel();
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+/*eoif5*/})();
+};
+});
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
