@@ -65,7 +65,7 @@ Clazz_declarePackage("JV");
 (function(){
 var c$ = Clazz_declareType(JV, "JmolStateCreator", null);
 })();
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
 Clazz_declarePackage("JV");
 Clazz_load(["JV.JmolStateCreator", "java.util.Hashtable"], "JV.StateCreator", ["java.util.Arrays", "$.Date", "JU.BS", "$.Lst", "$.P3", "$.PT", "$.SB", "J.c.PAL", "$.STR", "$.VDW", "JM.AtomCollection", "$.Bond", "$.BondSet", "JS.T", "J.shape.Shape", "JU.BSUtil", "$.C", "$.ColorEncoder", "$.Edge", "$.Escape", "$.Font", "$.Logger", "JV.GlobalSettings", "$.JC", "$.StateManager", "$.Viewer"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -216,17 +216,19 @@ if (mset != null) JU.BSUtil.setMapBitSet(temp, j, j, mset.getState());
 }
 commands.append(this.getCommands(temp, null, "select"));
 }}sb.setLength(0);
-for (var i = 0; i < ms.bondCount; i++) if (!models[bonds[i].atom1.mi].isModelKit) if (bonds[i].isHydrogen() || (bonds[i].order & 131072) != 0) {
+for (var i = 0; i < ms.bondCount; i++) {
+if (bonds[i] != null && !models[bonds[i].atom1.mi].isModelKit) {
+if (bonds[i].isHydrogen() || (bonds[i].order & 131072) != 0) {
 var bond = bonds[i];
 var index = bond.atom1.i;
 if (bond.atom1.group.isAdded(index)) index = -1 - index;
-sb.appendI(index).appendC('\t').appendI(bond.atom2.i).appendC('\t').appendI(bond.order & 131071).appendC('\t').appendF(bond.mad / 1000).appendC('\t').appendF(bond.getEnergy()).appendC('\t').append(JU.Edge.getBondOrderNameFromOrder(bond.order)).append(";\n");
-}
+sb.appendI(index).appendC('\t').appendI(bond.atom2.i).appendC('\t').appendI(bond.order & 131071).appendC('\t').appendD(bond.mad / 1000).appendC('\t').appendD(bond.getEnergy()).appendC('\t').append(JU.Edge.getBondOrderNameFromOrder(bond.order)).append(";\n");
+}}}
 if (sb.length() > 0) commands.append("data \"connect_atoms\"\n").appendSB(sb).append("end \"connect_atoms\";\n");
 commands.append("\n");
 }if (ms.haveHiddenBonds) {
 var bs =  new JM.BondSet();
-for (var i = ms.bondCount; --i >= 0; ) if (bonds[i].mad != 0 && (bonds[i].shapeVisibilityFlags & JM.Bond.myVisibilityFlag) == 0) bs.set(i);
+for (var i = ms.bondCount; --i >= 0; ) if (bonds[i] != null && bonds[i].mad != 0 && (bonds[i].shapeVisibilityFlags & JM.Bond.myVisibilityFlag) == 0) bs.set(i);
 
 if (bs.isEmpty()) ms.haveHiddenBonds = false;
  else commands.append("  hide ").append(JU.Escape.eBond(bs)).append(";\n");
@@ -704,26 +706,26 @@ var bsOrderSet = shape.bsOrderSet;
 var reportAll = shape.reportAll;
 this.clearTemp();
 var modelSet = this.vwr.ms;
-var haveTainted = false;
 var bonds = modelSet.bo;
 var bondCount = modelSet.bondCount;
 var r;
 if (reportAll || shape.bsSizeSet != null) {
 var i0 = (reportAll ? bondCount - 1 : shape.bsSizeSet.nextSetBit(0));
-for (var i = i0; i >= 0; i = (reportAll ? i - 1 : shape.bsSizeSet.nextSetBit(i + 1))) JU.BSUtil.setMapBitSet(this.temp, i, i, "wireframe " + ((r = bonds[i].mad) == 1 ? "on" : "" + JU.PT.escF(r / 2000)));
+for (var i = i0; i >= 0; i = (reportAll ? i - 1 : shape.bsSizeSet.nextSetBit(i + 1))) if (bonds[i] != null) JU.BSUtil.setMapBitSet(this.temp, i, i, "wireframe " + ((r = bonds[i].mad) == 1 ? "on" : "" + JU.PT.escF(r / 2000)));
 
 }if (reportAll || bsOrderSet != null) {
 var i0 = (reportAll ? bondCount - 1 : bsOrderSet.nextSetBit(0));
 for (var i = i0; i >= 0; i = (reportAll ? i - 1 : bsOrderSet.nextSetBit(i + 1))) {
 var bond = bonds[i];
-if (reportAll || (bond.order & 131072) == 0) JU.BSUtil.setMapBitSet(this.temp, i, i, "bondOrder " + JU.Edge.getBondOrderNameFromOrder(bond.order));
+if (bond != null && (reportAll || (bond.order & 131072) == 0)) JU.BSUtil.setMapBitSet(this.temp, i, i, "bondOrder " + JU.Edge.getBondOrderNameFromOrder(bond.order));
 }
 }if (shape.bsColixSet != null) for (var i = shape.bsColixSet.nextSetBit(0); i >= 0; i = shape.bsColixSet.nextSetBit(i + 1)) {
+if (bonds[i] == null) continue;
 var colix = bonds[i].colix;
 if ((colix & -30721) == 2) JU.BSUtil.setMapBitSet(this.temp, i, i, J.shape.Shape.getColorCommand("bonds", J.c.PAL.CPK.id, colix, shape.translucentAllowed));
  else JU.BSUtil.setMapBitSet(this.temp, i, i, J.shape.Shape.getColorCommandUnk("bonds", colix, shape.translucentAllowed));
 }
-var s = this.getCommands(this.temp, null, "select BONDS") + "\n" + (haveTainted ? this.getCommands(this.temp2, null, "select BONDS") + "\n" : "");
+var s = this.getCommands(this.temp, null, "select /*16.2*/ BONDS") + "\n";
 this.clearTemp();
 return s;
 }, "J.shape.Sticks");
@@ -1204,7 +1206,7 @@ this.actionStates.removeItemAt(99);
 this.undoWorking = !clearRedo;
 }, "~N,~N,~B");
 });
-;//5.0.1-v2 Tue Jul 23 17:25:20 CDT 2024
+;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
 })(Clazz
 ,Clazz.getClassName
 ,Clazz.newLongArray
